@@ -140,12 +140,12 @@ process_gps <- function(gps, shps, x, gm, nx, interactive, return.asp) {
 		matchIDs <- lapply(shps, function(s) if (inherits(s, "Raster")) s[] else s$tmapID)
 		matchIDs <- lapply(1:nx, function(i) matchIDs)
 	}
-	
 	gps <- mapply(function(gp, masterID) {
 		gp[1:gm$shape.nshps] <- mapply(function(gpl, indices, l) {
+			npol_old <- gpl$npol
 			gpl$npol <- length(indices)
 			lapply(gpl, function(gplx) {
-				if ((is.vector(gplx) || is.factor(gplx)) && length(gplx)==l) {
+				if ((is.vector(gplx) || is.factor(gplx)) && length(gplx)==npol_old) {
 					gplx[indices]	
 				} else {
 					gplx
